#
# Create a security group for the jumphost
#
/*
module "jumphost_sg" {
  source = "terraform-aws-modules/security-group/aws"

  name        = format("%s-jumphost-%s", var.prefix, var.random.hex)
  description = "Security group for BIG-IP Demo"
  vpc_id      = var.vpcid

  ingress_cidr_blocks = [var.allowed_mgmt_cidr]
  ingress_rules       = ["https-443-tcp", "ssh-tcp"]
  ingress_with_cidr_blocks = [
    {
      from_port   = 3300
      to_port     = 3300
      protocol    = "tcp"
      description = "Juiceshop ports"
      cidr_blocks = var.allowed_mgmt_cidr
    },
    {
      from_port   = 3000
      to_port     = 3000
      protocol    = "tcp"
      description = "Juiceshop ports"
      cidr_blocks = var.allowed_mgmt_cidr
    },
  ]

  # Allow ec2 instances outbound Internet connectivity
  egress_cidr_blocks = ["0.0.0.0/0"]
  egress_rules       = ["all-all"]
}
*/
#
# Create and place the inventory.yml file for the ansible demo
#
resource "null_resource" "hostvars" {
  count = var.instance_count
  provisioner "file" {
    content = templatefile(
      "${path.module}/files/hostvars_template.yml",
      {
        # bigip_host_ip          = join(",", (for_each(var.public_nic_ids), count.index))
        bigip_host_ip          = var.bigip_mgmt_addr[count.index]  # the ip address that the bigip has on the management subnet
        bigip_host_dns         = var.bigip_mgmt_dns[count.index]                      # the DNS name of the bigip on the public subnet
        bigip_domain           = "${var.region}.compute.internal"
        bigip_username         = "admin"
        bigip_password         = var.bigip_password[count.index]
        ec2_key_name           = var.keyname
        ec2_username           = "ubuntu"
        log_pool               = cidrhost(cidrsubnet(var.cidr, 8, count.index + var.internal_subnet_offset), 250)
        bigip_external_self_ip = element(flatten(data.aws_network_interface.bar[count.index].private_ips), 0) # the ip address that the bigip has on the public subnet
        bigip_internal_self_ip = var.bigip_private_add[count.index]                      # the ip address that the bigip has on the private subnet
        juiceshop_virtual_ip   = element(flatten(data.aws_network_interface.bar[count.index].private_ips), 1)
        grafana_virtual_ip     = element(flatten(data.aws_network_interface.bar[count.index].private_ips), 2)
        appserver_gateway_ip   = cidrhost(cidrsubnet(var.cidr, 8, count.index + var.internal_subnet_offset), 1)
        appserver_guest_ip     = var.docker_private_ip[count.index]
        // appserver_host_ip      = module.jumphost.private_ip[count.index] # the ip address that the jumphost has on the public subnet
        bigip_dns_server       = "8.8.8.8"
      }
    )

    destination = "/home/ubuntu/inventory.yml"

    connection {
      type        = "ssh"
      user        = "ubuntu"
      private_key = file(var.keyfile)
      host        = var.remote[0]
    }
  }
}

#
# sleep for cloud-init to work
# TODO: add check for cloud-init completion
resource "time_sleep" "wait_3_minutes" {
  depends_on = [null_resource.hostvars]

  create_duration = "3m"
}
#
# Hack for remote exec of provisioning
#
resource "null_resource" "ansible" {
  depends_on = [time_sleep.wait_3_minutes]
  count      = var.instance_count
  provisioner "file" {
    source      = var.keyfile
    destination = "/home/ubuntu/.ssh/${var.keyname}.pem"

    connection {
      type        = "ssh"
      user        = "ubuntu"
      private_key = file(var.keyfile)
      host        = var.remote[count.index]
    }
  }

  provisioner "remote-exec" {
    inline = [
      "chmod 600 /home/ubuntu/.ssh/${var.keyname}.pem",
      "git clone -b cloud-init --single-branch https://github.com/merps/ansible-uber-demo.git",
      "cp /home/ubuntu/inventory.yml /home/ubuntu/ansible-uber-demo/ansible/inventory.yml",
      "cd /home/ubuntu/ansible-uber-demo/",
      "/usr/bin/ansible-galaxy install -r ansible/requirements.yml",
      "/usr/bin/sudo /usr/bin/ansible-playbook ansible/playbooks/site.yml"
    ]

    connection {
      type        = "ssh"
      timeout     = "10m"
      user        = "ubuntu"
      private_key = file(var.keyfile)
      host        = var.remote[count.index]
    }
  }
}

data "aws_network_interface" "bar" {
  count = length(var.public_nic_ids)
  id    = var.public_nic_ids[count.index]
}
/*
## TODO: update inventory.yml to pull EIP's created on cbip module
resource "aws_eip" "juiceshop" {
  depends_on                = [null_resource.hostvars]
  count                     = var.instance_count
  vpc                       = true
  network_interface         = data.aws_network_interface.bar[count.index].id
  associate_with_private_ip = element(flatten(data.aws_network_interface.bar[count.index].private_ips), 1)
  tags = {
    Name = format("%s-juiceshop-eip-%s%s", var.prefix, var.random.hex, count.index)
  }
}

resource "aws_eip" "grafana" {
  depends_on                = [null_resource.hostvars]
  count                     = var.instance_count
  vpc                       = true
  network_interface         = data.aws_network_interface.bar[count.index].id
  associate_with_private_ip = element(flatten(data.aws_network_interface.bar[count.index].private_ips), 2)
  tags = {
    Name = format("%s-grafana-eip-%s%s", var.prefix, var.random.hex, count.index)
  }
}
*/