#
# Create the BIG-IP appliances
#
module "bigip" {
  source = "github.com/f5networks/terraform-aws-bigip-module"

  prefix = format(
    "%s-bigip-3-nic_with_new_vpc-%s",
    var.prefix,
    var.random.hex
  )
  // aws_secretmanager_secret_id = aws_secretsmanager_secret.bigip.id

  f5_ami_search_name          = "F5 BIGIP-16.* PAYG-Best 200Mbps*"
  ec2_key_name                = var.keyname
  ec2_instance_type           = "m5.xlarge"

  mgmt_securitygroup_ids = [
    module.bigip_sg.security_group_id,
    module.bigip_mgmt_sg.security_group_id
  ]

  external_securitygroup_ids = [
    module.bigip_sg.security_group_id,
    module.bigip_mgmt_sg.security_group_id
  ]

  internal_securitygroup_ids = [
    module.bigip_sg.security_group_id,
    module.bigip_mgmt_sg.security_group_id
  ]

  mgmt_subnet_ids = [{ "subnet_id" = var.database_subnets[var.instance_count], "public_ip" = true, "private_ip_primary" = "" }]
  external_subnet_ids  = [{ "subnet_id" = var.public_subnets[var.instance_count], "public_ip" = true, "private_ip_primary" = "", "private_ip_secondary" = "" }]
  internal_subnet_ids = [{ "subnet_id" = var.private_subnets[var.instance_count], "public_ip" = false, "private_ip_primary" = ""}]
}
#
# Create a security group for BIG-IP
#
module "bigip_sg" {
  source = "terraform-aws-modules/security-group/aws"

  name        = format("%s-bigip-%s", var.prefix, var.random.hex)
  description = "Security group for BIG-IP Demo"
  vpc_id      = var.vpcid

  ingress_cidr_blocks = [var.allowed_app_cidr]
  ingress_rules       = ["http-80-tcp", "https-443-tcp"]

  ingress_with_source_security_group_id = [
    {
      rule                     = "all-all"
      source_security_group_id = module.bigip_sg.security_group_id
    }
  ]

  # Allow ec2 instances outbound Internet connectivity
  egress_cidr_blocks = ["0.0.0.0/0"]
  egress_rules       = ["all-all"]
}
#
# Create a security group for BIG-IP Management
#
module "bigip_mgmt_sg" {
  source = "terraform-aws-modules/security-group/aws"

  name        = format("%s-bigip-mgmt-%s", var.prefix, var.random.hex)
  description = "Security group for BIG-IP Demo"
  vpc_id      = var.vpcid

  ingress_cidr_blocks = [var.allowed_mgmt_cidr]
  ingress_rules       = ["https-443-tcp", "https-8443-tcp", "ssh-tcp"]

  ingress_with_source_security_group_id = [
    {
      rule                     = "all-all"
      source_security_group_id = module.bigip_mgmt_sg.security_group_id
    }
  ]

  # Allow ec2 instances outbound Internet connectivity
  egress_cidr_blocks = ["0.0.0.0/0"]
  egress_rules       = ["all-all"]
}
/*
## TODO: Provision ASM via DO for spin up and AS3 support
*/